==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutRenderStyleUpdatingEventArgsDescription } from "./CalloutRenderStyleUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutRenderStyleUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutRenderStyleUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.c(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.j(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("LabelPositionX", "Number:double");
            a.item("LabelPositionY", "Number:double");
            a.item("TargetPositionX", "Number:double");
            a.item("TargetPositionY", "Number:double");
            a.item("ActualPosition", "ExportedType:string:CalloutPlacementPositions");
            a.item("ActualPosition@names", "Top;Left;Right;Bottom;TopLeft;TopRight;BottomLeft;BottomRight");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("Background", "Brush");
            a.item("TextColor", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.b(a);
            a.aa("CalloutRenderStyleUpdatingEventArgs", () => new CalloutRenderStyleUpdatingEventArgsDescription());
            a.z("CalloutRenderStyleUpdatingEventArgs", CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata, 'CalloutRenderStyleUpdatingEventArgsDescriptionMetadata');
    CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutRenderStyleUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutRenderStyleUpdatingEventArgsDescription } from "./CalloutRenderStyleUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutRenderStyleUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutRenderStyleUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.c(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("LabelPositionX", "Number:double");
            a.item("LabelPositionY", "Number:double");
            a.item("TargetPositionX", "Number:double");
            a.item("TargetPositionY", "Number:double");
            a.item("ActualPosition", "ExportedType:string:CalloutPlacementPositions");
            a.item("ActualPosition@names", "Top;Left;Right;Bottom;TopLeft;TopRight;BottomLeft;BottomRight");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("Background", "Brush");
            a.item("TextColor", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
        }
        static d(a) {
            CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.b(a);
            a.ac("CalloutRenderStyleUpdatingEventArgs", () => new CalloutRenderStyleUpdatingEventArgsDescription());
            a.ab("CalloutRenderStyleUpdatingEventArgs", CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CalloutRenderStyleUpdatingEventArgsDescriptionMetadata, 'CalloutRenderStyleUpdatingEventArgsDescriptionMetadata');
    CalloutRenderStyleUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutRenderStyleUpdatingEventArgsDescriptionMetadata;
})();
